<?php
session_start();
//session_unset(); exit();
require_once('config.php');

require_once('osm-liboauth.php');
require_once('dbutils.php');
$users = new GenericSqliteTable("var/users.db","users");
$userToId = new GenericSqliteTable("var/userToId.db","userToId");
$idToUser = new GenericSqliteTable("var/idToUser.db","idToUser");

//Check if user wants to clear their record in debug mode
if($debugMode and isset($_GET['zapme']))
{
	unset($users[$_SESSION['user_id']]);
	unset($userToId[$_SESSION['display_name']]);
	unset($idToUser[$_SESSION['user_id']]);
	session_unset();	
	die("Records cleared. Try <a href='.'>reloading the page</a>.");
}

//Disable test account if not in test mode
if($_SESSION['user_id']==-1 and !$debugMode)
	die("Test Account Disabled");

//Store association from user ID to display name
if(!isset($userToId[$_SESSION['display_name']]))
	$userToId[$_SESSION['display_name']] = array("id"=>$_SESSION['user_id']);

if(!isset($idToUser[$_SESSION['user_id']]))
	$idToUser[$_SESSION['user_id']] = array("display_name"=>$_SESSION['display_name']);

$userData = array();
if(isset($users[$_SESSION['user_id']]))
	$userData = $users[$_SESSION['user_id']];

//Read declarations into memory
$declarationFiles = glob("declarations/*.xml");
$declarations = array();
foreach($declarationFiles as $d)
{
	$xml = new SimpleXMLElement(file_get_contents($d));
	$expl = explode("/",$d);
	$declareId = substr($expl[1],0,strlen($expl[1])-4);
	$declarations[$declareId] = $xml;
}
//print_r($declarations);
?>
<link rel="stylesheet" type="text/css" href="default.css" />

<h1>Optional Licenses for OpenStreetMap</h1>
<?php
echo "<p>Welcome ".htmlspecialchars($_SESSION['display_name'])." (".$_SESSION['user_id'].")</p>";
?>

<p>As an OSM contributor, you have agreed to license your data to enable use and sharing by other map users. Specifically, your have shared your data by using CC-BY-SA 2.0 or the Contributor Terms, or both. This web site allows you to specify additional licenses beyond these basic two. Each license has it's own specific rights that are granted to the user by you, the contributor. Although all the licenses aim to enable open data, there are important differences in the rights a license grants. Some users are practically limited to particular types of licenses or have ideological preferences. By agreeing to share your data under this licenses, you help to promote data interoperability and make your contributed map data more "useful".</p>

<p>You are encouraged to share your data under a permissive license (marked by <img src="icon/zero.png" alt="No Limits" height="20px" width="20px"/>). This grants protential users the broadest range of rights. They also allow interoperability with all the other licenses, and saves you the effort in agreeing to every license listed! <a href="faq.php">Information is available on helping you to choose which license to use.</a></p>

<?php
//Generate license characterstic icons
function XmlToIcons($d)
{
	$out = "";
	foreach($d->attributes() as $k => $v)
	{
		if($k == "creativecommons" and $v == "yes")
			$out .= '<a href="http://creativecommons.org/"><img src="icon/cc.png" height="20px" width="20px" alt="Creative Commons"/></a>';
		if($k == "by" and $v == "yes")
			$out .= '<img src="icon/by.png" height="20px" width="20px" alt="Attribution"/>';
		if($k == "sharealike" and $v == "yes")
			$out .= '<img src="icon/sa.png" height="20px" width="20px" alt="Sharealike"/>';
		if($k == "noderivs" and $v == "yes")
			$out .= '<img src="icon/nd.png" height="20px" width="20px" alt="No derivatives"/>';
		if($k == "noncommercial" and $v == "yes")
			$out .= '<img src="icon/nc.png" height="20px" width="20px" alt="Non-commercial"/>';
		if($k == "nolimits" and $v == "yes")
			$out .= '<img src="icon/zero.png" alt="No Limits" height="20px" width="20px"/>';
		if($k == "preferred" and $v == "yes")
			$out .= '<img src="icon/Dialog-information_on.png" alt="Preferred" height="20px" width="20px"/>';
 	}
	return $out;
}

//Display user's additional licenses
$myDeclarations = array();
if(isset($userData['declarations']))
	$myDeclarations = $userData['declarations'];
$declAccepted = array();
?>

<div id="toolbars">
<div id="keybar">
<h2>Key</h2>
<p>
<a href="http://creativecommons.org/"><img src="icon/cc.png" height="20px" width="20px" alt="Creative Commons"/></a>
<a href="http://creativecommons.org/">Creative Commons</a><br/>
<img src="icon/by.png" height="20px" width="20px" alt="Attribution"/> Requires Attribution<br/>
<img src="icon/sa.png" height="20px" width="20px" alt="Sharealike"/> Requires Share-alike<br/>
<img src="icon/nd.png" height="20px" width="20px" alt="No derivatives"/> No derivatives allowed<br/>
<img src="icon/nc.png" height="20px" width="20px" alt="Non-commercial"/> No commerical use allowed<br/>
<img src="icon/zero.png" alt="No Limits" height="20px" width="20px"/> No limits to use<br/>
<img src="icon/Dialog-information_on.png" alt="Preferred" height="20px" width="20px"/> Recommended licenses<br/>
</p>
</div>

<div id="linkbar">
<h2>Links</h2>
<p><a href="http://www.openstreetmap.org/user/<?php echo htmlspecialchars($_SESSION['display_name']);?>">My OSM Profile</a></p>
<p>Machine Readable Record<br/>
<a href="declared.php?display_name=<?php echo htmlspecialchars($_SESSION['display_name']);?>">by Display Name</a><br/>
<a href="declared.php?user_id=<?php echo $_SESSION['user_id'];?>">by User ID</a><br/>
<p>Human Readable Record<br/>
<a href="declaredHuman.php?display_name=<?php echo htmlspecialchars($_SESSION['display_name']);?>">by Display Name</a><br/>
<a href="declaredHuman.php?user_id=<?php echo $_SESSION['user_id'];?>">by User ID</a><br/>
<a href="log/log.txt">View Log</a></p>
</div>
</div>

<?php
if(count($myDeclarations) > 0)
{
?>
<h2>Your Extra Licenses</h2>
<table border="1">
<tr><td>License</td><td>Date Accepted</td><td>Options</td></tr>
<?php
foreach($myDeclarations as $d)
{
if(!in_array($d['decl'],$declAccepted))
	array_push($declAccepted, (string)$d['decl']);
$decl = $declarations[$d['decl']];
echo "<tr>";
echo '<td><a href="view.php?declare='.$d['decl'].'">'.$decl->name."</a> ".XmlToIcons($decl)."</td>";
echo "<td>".date(DATE_RFC822,$d['time'])."</td>";
echo "<td>";
$countOptions = 0;
foreach($d['options'] as $k => $v)
{
	if($countOptions > 0) echo ", ";
	echo $v;
	$countOptions++;
}
echo "</td>";
echo "</tr>\n";
}
?>
</table>
<?php
}

//Show list of extra licenses
?>
<h2>View Licenses</h2>
<p>Please view the specific license you are interested in, before accepting it.</p>
<ul>
<?php

foreach($declarations as $declareId => $d)
{
	if(in_array($declareId, $declAccepted)) continue; //Skip licenses already accepted
?>
<li><a href="details.php?declare=<?php echo $declareId; ?>"><?php echo $d->name; ?></a> <?php echo XmlToIcons($d);?></li>
<?php
}
?>
</ul>



<?php
if($debugMode)
{
?>
<h2>Debug Options</h2>
<p><a href="?zapme=yes">Zap My Records</a>: this clears database and session variables associated with your account. All licenses are cleared. This feature can be disabled by setting $debugMode to 0.</p>

<?php
}
?>

<p>The data and content on this site is provided under the terms of <a href="http://creativecommons.org/publicdomain/zero/1.0/legalcode">CC0</a>. The site maintainers offers the data and content as-is and makes no representations or warranties of any kind.</p>
